@@ -38,6 +38,55 @@ class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
         db_table = 'cliente_endereco'
 
 
+class Cartao(core.models.Log):
+    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
+    cliente_token = models.CharField(max_length=200, null=True)
+    cartao_token = models.CharField(max_length=200, null=True)
+
+    ultimos_4 = models.CharField(max_length=4, null=True)
+    nm_impresso = models.CharField(max_length=200, null=True)
+    dat_val = models.CharField(max_length=5, null=True)
+    bandeira = models.ForeignKey('cliente.CartaoBandeira', on_delete=models.DO_NOTHING, null=True)
+
+    tipo_codigo = models.CharField(null=True, max_length=200)
+    tipo_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CARTAO')
+    tipo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cartao', to_fields={
+        "codigo": "tipo_codigo",
+        "tipo": "tipo_tipo"
+    })
+
+    adquirente_codigo = models.CharField(null=True, max_length=200)
+    adquirente_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.CARTAO.ADQUIRENTE')
+    adquirente = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='cliente_cartao_adquirente', to_fields={
+        "codigo": "tipo_codigo",
+        "tipo": "tipo_tipo"
+    })
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'cliente_cartao'
+
+
+class CartaoBandeira(core.models.Log):
+    nome = models.CharField(max_length=50, primary_key=True)
+    nm_descritivo = models.CharField(max_length=200, null=True)
+    imagem = models.FileField(upload_to="bandeiras", default='bandeiras/sem-imagem.jpg', null=True)
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'cliente_cartaobandeira'
+
+
+class CartaoBandeiraParcela(core.models.Log):
+    bandeira = models.ForeignKey('cliente.CartaoBandeira', on_delete=models.DO_NOTHING, null=True)
+    quantidade = models.IntegerField(default=1, null=True)
+    is_juros = models.BooleanField(default=False, null=True)
+
+    class Meta(core.models.Log.Meta):
+        abstract = False
+        db_table = 'cliente_cartaobandeiraparcela'
+
+
 class Termo(core.models.Log):
     nome = models.CharField(max_length=200, primary_key=True)
     nome_descritivo = models.CharField(max_length=200, null=True)
@@ -86,14 +135,6 @@ class Avaliacao(core.models.Log):
         db_table = 'cliente_avaliacao'
 
 
-class Cartao(core.models.Log):
-    cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
-
-    class Meta(core.models.Log.Meta):
-        abstract = False
-        db_table = 'cliente_cartao'
-
-
 class Favorito(core.models.Log):
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
 
