@@ -186,9 +186,10 @@ class PessoaLog(ContatoLog):
 
 class EnderecoLog(models.Model):
     cep = models.CharField(max_length=10, null=True)
+    cep_form = models.CharField(max_length=15, null=True)
     municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
-    bairro = models.CharField(max_length=100, null=True)
-    rua = models.CharField(max_length=100, null=True)
+    bairro_cep = models.CharField(max_length=100, null=True)
+    rua_cep = models.CharField(max_length=100, null=True)
     latitude_cep = models.CharField(max_length=200, null=True)
     longitude_cep = models.CharField(max_length=200, null=True)
 
@@ -200,6 +201,9 @@ class EnderecoComplementoLog(models.Model):
     cep = models.ForeignKey('core.Cep', null=True, on_delete=models.DO_NOTHING)
     numero = models.CharField(max_length=30, null=True)
     complemento = models.CharField(max_length=100, null=True)
+    bairro = models.CharField(max_length=100, null=True)
+    rua = models.CharField(max_length=100, null=True)
+
     ponto_referencia = models.CharField(max_length=100, null=True)
     latitude = models.CharField(max_length=200, null=True)
     longitude = models.CharField(max_length=200, null=True)
